==> crowdin-api-client-1.5.0.tar.gz: crowdin-api-client-1.5.0/crowdin_api/api_resources/__init__.py <==
from .bundles.resource import BundlesResource
from .dictionaries.resource import DictionariesResource
from .distributions.resource import DistributionsResource
from .glossaries.resource import GlossariesResource
from .groups.resource import GroupsResource
from .labels.resource import LabelsResource
from .languages.resource import LanguagesResource
from .machine_translation_engines.resource import MachineTranslationEnginesResource
from .projects.resource import ProjectsResource
from .reports.resource import ReportsResource, EnterpriseReportsResource
from .screenshots.resource import ScreenshotsResource
from .source_files.resource import SourceFilesResource
from .source_strings.resource import SourceStringsResource
from .storages.resource import StoragesResource
from .string_comments.resource import StringCommentsResource
from .string_translations.resource import StringTranslationsResource
from .tasks.resource import TasksResource
from .teams.resource import TeamsResource
from .translation_memory.resource import TranslationMemoryResource
from .translation_status.resource import TranslationStatusResource
from .translations.resource import TranslationsResource
from .users.resource import UsersResource, EnterpriseUsersResource
from .vendors.resource import VendorsResource
from .webhooks.resource import WebhooksResource
from .workflows.resource import WorkflowsResource

__all__ = [
    "BundlesResource",
    "DictionariesResource",
    "DistributionsResource",
    "GlossariesResource",
    "GroupsResource",
    "LabelsResource",
    "LanguagesResource",
    "MachineTranslationEnginesResource",
    "ProjectsResource",
    "ReportsResource",
    "EnterpriseReportsResource",
    "ScreenshotsResource",
    "SourceFilesResource",
    "SourceStringsResource",
    "StoragesResource",
    "StringCommentsResource",
    "StringTranslationsResource",
    "TasksResource",
    "TeamsResource",
    "TranslationMemoryResource",
    "TranslationStatusResource",
    "TranslationsResource",
    "UsersResource",
    "EnterpriseUsersResource",
    "VendorsResource",
    "WebhooksResource",
    "WorkflowsResource",
]

==> crowdin-api-client-1.8.0.tar.gz: crowdin-api-client-1.8.0/crowdin_api/api_resources/__init__.py <==
from .bundles.resource import BundlesResource
from .dictionaries.resource import DictionariesResource
from .distributions.resource import DistributionsResource
from .glossaries.resource import GlossariesResource
from .groups.resource import GroupsResource
from .labels.resource import LabelsResource
from .languages.resource import LanguagesResource
from .machine_translation_engines.resource import MachineTranslationEnginesResource
from .projects.resource import ProjectsResource
from .reports.resource import ReportsResource, EnterpriseReportsResource
from .screenshots.resource import ScreenshotsResource
from .source_files.resource import SourceFilesResource
from .source_strings.resource import SourceStringsResource
from .storages.resource import StoragesResource
from .string_comments.resource import StringCommentsResource
from .string_translations.resource import StringTranslationsResource
from .tasks.resource import TasksResource, EnterpriseTasksResource
from .teams.resource import TeamsResource
from .translation_memory.resource import TranslationMemoryResource
from .translation_status.resource import TranslationStatusResource
from .translations.resource import TranslationsResource
from .users.resource import UsersResource, EnterpriseUsersResource
from .vendors.resource import VendorsResource
from .webhooks.resource import WebhooksResource
from .workflows.resource import WorkflowsResource

__all__ = [
    "BundlesResource",
    "DictionariesResource",
    "DistributionsResource",
    "GlossariesResource",
    "GroupsResource",
    "LabelsResource",
    "LanguagesResource",
    "MachineTranslationEnginesResource",
    "ProjectsResource",
    "ReportsResource",
    "EnterpriseReportsResource",
    "ScreenshotsResource",
    "SourceFilesResource",
    "SourceStringsResource",
    "StoragesResource",
    "StringCommentsResource",
    "StringTranslationsResource",
    "TasksResource",
    "EnterpriseTasksResource",
    "TeamsResource",
    "TranslationMemoryResource",
    "TranslationStatusResource",
    "TranslationsResource",
    "UsersResource",
    "EnterpriseUsersResource",
    "VendorsResource",
    "WebhooksResource",
    "WorkflowsResource",
]
